@@ -6,18 +6,18 @@ import os
 import sys
 
 import tornado
-from tornado.web import UIModule
+from tornado.web import UIModule, StaticFileHandler
 from tornado import web, iostream
 from tornado.ioloop import IOLoop
 from tornado.locks import Condition
-from tornado.options import options
+from tornado.options import options, define
 from tornado.process import Subprocess
-from tornado.concurrent import run_on_executor, TracebackFuture
+from tornado.concurrent import run_on_executor, Future
 from tornado import gen, web, httpserver, ioloop
 from tornado.gen import coroutine, Return, Task, sleep
 from tornado.httpclient import HTTPClient, AsyncHTTPClient, HTTPError, HTTPRequest
 
-from kombu import Queue, Exchange
+from kombu import Queue as RMQueue, Exchange
 from celery.exceptions import Ignore
 from celery import Task as CeleryTask, platforms, Celery, task, states
 from celery.schedules import crontab
@@ -29,8 +29,10 @@ from thrift.protocol import TBinaryProtocol, TCompactProtocol
 
 if sys.version_info < (3, 0):
     from subprocess32 import Popen
+    from Queue import Queue, Empty, Full
 else:
     from subprocess import Popen
+    from queue import Empty, Full, Queue
 
 from docopt import docopt
 
@@ -40,4 +42,7 @@ import tornado_mysql
 from zeep import CachingClient
 from zeep.exceptions import Error
 from zeep.wsse.username import UsernameToken
-from zeep.transports import Transport
\ No newline at end of file
+from zeep.transports import Transport
+
+import requests
+from requests.exceptions import HTTPError as RequestHTTPError
\ No newline at end of file
