@@ -10,7 +10,7 @@ from fastweb.spec import torcelery
 from fastweb.util.tool import timing
 from fastweb.component import Component
 from fastweb.exception import TaskError
-from fastweb.accesspoint import CeleryTask, Celery, Queue, Exchange, coroutine, Return, crontab
+from fastweb.accesspoint import CeleryTask, Celery, RMQueue, Exchange, coroutine, Return, crontab
 
 from celery.loaders.base import BaseLoader
 
@@ -48,6 +48,8 @@ class Task(Component, CeleryTask):
         rate_limit = self.setting.get('rate_limit', None)
         acks_late = self.setting.get('acks_late', None)
         self.requestid = None
+        # 设置跟踪任务启动状态，为了让异步访问时可以准确知道任务被执行了
+        self.track_started = True
 
         # 定时任务
         minute = setting.get('minute', '*')
@@ -74,7 +76,7 @@ class Task(Component, CeleryTask):
         self.recorder('DEBUG', 'setup crontab {cron}'.format(cron=beat_schedule))
 
         # 设置任务的路由
-        queue = Queue(name=self.queue, exchange=Exchange(name=self.exchange, type=self.exchange_type), routing_key=self.routing_key)
+        queue = RMQueue(name=self.queue, exchange=Exchange(name=self.exchange, type=self.exchange_type), routing_key=self.routing_key)
         app.conf.update(task_queues=(queue,),
                         task_routes={self.name: {'queue': self.queue, 'routing_key': self.routing_key}},
                         task_annotations={self.name: {'rate_limit': rate_limit}},
@@ -187,6 +189,6 @@ class AsynTask(Task):
 
         self.recorder('INFO', 'synchronize call {obj} successful\n'
                               'Return:{ret} -- {t}'.format(obj=self,
-                                                                                         ret=result,
-                                                                                         t=t))
+                                                           ret=result,
+                                                           t=t))
         raise Return(result)
