@@ -11,6 +11,7 @@ from .accesspoint import ioloop
 
 import fastweb.manager
 from fastweb.util.tool import timing
+from fastweb.accesspoint import AsyncHTTPClient
 from fastweb.util.configuration import Configuration
 from fastweb.util.log import setup_logging, getLogger, recorder, check_logging_level, set_record_color
 
@@ -40,6 +41,9 @@ class Loader(object):
         # 日志是否被设置过
         self.bRecorder = False
 
+        # 增加最大数据量
+        AsyncHTTPClient.configure(None, max_body_size=1000000000)
+
     def load_recorder(self, application_log_path=DEFAULT_APP_LOG_PATH, system_log_path=DEFAULT_SYS_LOG_PATH, logging_setting=None,
                       application_level='DEBUG', system_level='DEBUG', logging_colormap=None):
         """加载日志对象
