@@ -2,7 +2,7 @@
 
 """tornado调用celery模块"""
 
-from fastweb.accesspoint import states, IOLoop, TracebackFuture
+from fastweb.accesspoint import states, IOLoop, Future
 
 
 def async(task, *args, **kwargs):
@@ -10,7 +10,7 @@ def async(task, *args, **kwargs):
 
     异步给celery发送命令时，任务的状态为PENDING则视为成功，将任务的taskid返回"""
 
-    future = TracebackFuture()
+    future = Future()
     callback = kwargs.pop("callback", None)
     if callback:
         IOLoop.instance().add_future(future, lambda f: callback(f.result()))
@@ -29,7 +29,7 @@ def sync(task, timeout, *args, **kwargs):
       - `timeout`: 超时时间
     """
 
-    future = TracebackFuture()
+    future = Future()
     callback = kwargs.pop("callback", None)
     if callback:
         IOLoop.instance().add_future(future, lambda f: callback(f.result()))
@@ -39,7 +39,7 @@ def sync(task, timeout, *args, **kwargs):
 
 
 def _on_async_result(result, future):
-    if result.state == states.PENDING:
+    if result.state == states.STARTED:
         future.set_result(result.task_id)
     else:
         IOLoop.instance().add_callback(_on_async_result, result, future)
@@ -47,10 +47,9 @@ def _on_async_result(result, future):
 
 def _on_sync_result(result, future, start_time, timeout):
     if IOLoop.instance().time()-start_time < timeout:
-        if result.successful():
+        if result.ready():
             future.set_result(result.result)
         else:
             IOLoop.instance().add_callback(_on_sync_result, result, future, start_time, timeout)
     else:
-        print('xxxx')
         future.set_result(None)
