@@ -10,13 +10,13 @@ from fastweb.util.tool import timing
 def test():
     conn = yield tornado_mysql.connect(**{'host': 'localhost', 'port': 3306, 'user': 'root', 'password': '1a2s3dqwe'})
     with timing('ms', 10) as ti:
-        for _ in xrange(30):
+        for _ in range(30):
             cur = conn.cursor(tornado_mysql.cursors.DictCursor)
             with timing('ms', 10) as t:
                 yield cur.execute('SELECT * FROM mysql.user;')
-            print t
+            print(t)
 
-    print 'total:'
-    print ti
+    print('total:')
+    print(ti)
 
 ioloop.IOLoop.current().run_sync(test)
